.. image:: images/zhinst_logo_sep_horiz_2019_1000.png
   :width: 400
   :target: https://www.zhinst.com
   :alt: ""

|

Zurich Instruments Toolkit |version| Documentation
==================================================

zhinst-toolkit is a high level driver package that allows communication with
Zurich Instruments devices from the Python programming language. It is based on
top of the native `Python API <https://pypi.org/project/zhinst/>`_
(``zhinst.core``) of LabOne®, the Zurich Instruments control software.

The central goal of zhinst-toolkit is to provide a Pythonic approach to interact
with any Zurich Instruments device and is intended as a full replacement for the
low level ``zhinst.core`` package.

zhinst-toolkit is published under the :ref:`MIT License <license/index:License>`
and contributions are highly welcome. (Before you invest a lot of time into a new
feature or adaption we recommend getting in touch with us so that we can give
you some insights into our planning.)

Get started with the :ref:`first_steps/installation:Installation` and then get
an overview with the :ref:`first_steps/quickstart:Quickstart` guide.



.. toctree::
   :maxdepth: 2
   :caption: Contents

   first_steps/index
   examples/index
   package_documentation
   changelog/index
   contributing/index
   license/index
   about/index



Index
=====
* :ref:`genindex`
